@@ -400,11 +400,12 @@ int buildquotalist(char *domain, char **roots, int nroots)
 
 static int findroot(const char *name, int *thisquota)
 {
-    int i;
+    int i = config_getswitch(IMAPOPT_IMPROVED_MBOXLIST_SORT)
+            ? quota_todo : 0;
 
     *thisquota = -1;
 
-    for (i = quota_todo; i < quota_num; i++) {
+    for (; i < quota_num; i++) {
 	const char *root = quotaroots[i].name;
 
 	/* have we already passed the name, then there can
@@ -442,21 +443,23 @@ static int fixquota_dombox(void *rock,
     char *mboxname = xstrndup(name, namelen);
     struct txn *txn = NULL;
 
-    while (quota_todo < quota_num) {
-	const char *root = quotaroots[quota_todo].name;
+    if (config_getswitch(IMAPOPT_IMPROVED_MBOXLIST_SORT)) {
+	while (quota_todo < quota_num) {
+	    const char *root = quotaroots[quota_todo].name;
 
-	/* in the future, definitely don't close yet */
-	if (compar(mboxname, root) < 0)
-	    break;
+	    /* in the future, definitely don't close yet */
+	    if (compar(mboxname, root) < 0)
+		break;
 
-	/* inside the first root, don't close yet */
-	if (mboxname_is_prefix(mboxname, root))
-	    break;
+	    /* inside the first root, don't close yet */
+	    if (mboxname_is_prefix(mboxname, root))
+		break;
 
-	/* finished, close out now */
-	r = fixquota_finish(quota_todo);
-	quota_todo++;
-	if (r) goto done;
+	    /* finished, close out now */
+	    r = fixquota_finish(quota_todo);
+	    quota_todo++;
+	    if (r) goto done;
+	}
     }
 
     test_sync_wait(mboxname);
